@@ -218,14 +218,86 @@ anjuta_vcs_status_get_type (void)
 
 /* enumerations from "gbf-project.h" */
 GType
-if_if_get_type (void)
+gbf_project_error_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
+      { GBF_PROJECT_ERROR_SUCCESS, "GBF_PROJECT_ERROR_SUCCESS", "success" },
+      { GBF_PROJECT_ERROR_DOESNT_EXIST, "GBF_PROJECT_ERROR_DOESNT_EXIST", "doesnt-exist" },
+      { GBF_PROJECT_ERROR_ALREADY_EXISTS, "GBF_PROJECT_ERROR_ALREADY_EXISTS", "already-exists" },
+      { GBF_PROJECT_ERROR_VALIDATION_FAILED, "GBF_PROJECT_ERROR_VALIDATION_FAILED", "validation-failed" },
+      { GBF_PROJECT_ERROR_PROJECT_MALFORMED, "GBF_PROJECT_ERROR_PROJECT_MALFORMED", "project-malformed" },
+      { GBF_PROJECT_ERROR_GENERAL_FAILURE, "GBF_PROJECT_ERROR_GENERAL_FAILURE", "general-failure" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static (g_intern_static_string ("if"), values);
+    etype = g_enum_register_static (g_intern_static_string ("GbfProjectError"), values);
+  }
+  return etype;
+}
+GType
+gbf_project_capabilities_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { GBF_PROJECT_CAN_ADD_NONE, "GBF_PROJECT_CAN_ADD_NONE", "add-none" },
+      { GBF_PROJECT_CAN_ADD_GROUP, "GBF_PROJECT_CAN_ADD_GROUP", "add-group" },
+      { GBF_PROJECT_CAN_ADD_TARGET, "GBF_PROJECT_CAN_ADD_TARGET", "add-target" },
+      { GBF_PROJECT_CAN_ADD_SOURCE, "GBF_PROJECT_CAN_ADD_SOURCE", "add-source" },
+      { GBF_PROJECT_CAN_PACKAGES, "GBF_PROJECT_CAN_PACKAGES", "packages" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static (g_intern_static_string ("GbfProjectCapabilities"), values);
+  }
+  return etype;
+}
+
+/* enumerations from "anjuta-project.h" */
+GType
+anjuta_project_node_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { ANJUTA_PROJECT_UNKNOWN, "ANJUTA_PROJECT_UNKNOWN", "unknown" },
+      { ANJUTA_PROJECT_GROUP, "ANJUTA_PROJECT_GROUP", "group" },
+      { ANJUTA_PROJECT_TARGET, "ANJUTA_PROJECT_TARGET", "target" },
+      { ANJUTA_PROJECT_SOURCE, "ANJUTA_PROJECT_SOURCE", "source" },
+      { ANJUTA_PROJECT_VARIABLE, "ANJUTA_PROJECT_VARIABLE", "variable" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static (g_intern_static_string ("AnjutaProjectNodeType"), values);
+  }
+  return etype;
+}
+GType
+anjuta_project_target_class_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { ANJUTA_TARGET_UNKNOWN, "ANJUTA_TARGET_UNKNOWN", "unknown" },
+      { ANJUTA_TARGET_SHAREDLIB, "ANJUTA_TARGET_SHAREDLIB", "sharedlib" },
+      { ANJUTA_TARGET_STATICLIB, "ANJUTA_TARGET_STATICLIB", "staticlib" },
+      { ANJUTA_TARGET_EXECUTABLE, "ANJUTA_TARGET_EXECUTABLE", "executable" },
+      { ANJUTA_TARGET_PYTHON, "ANJUTA_TARGET_PYTHON", "python" },
+      { ANJUTA_TARGET_JAVA, "ANJUTA_TARGET_JAVA", "java" },
+      { ANJUTA_TARGET_LISP, "ANJUTA_TARGET_LISP", "lisp" },
+      { ANJUTA_TARGET_HEADER, "ANJUTA_TARGET_HEADER", "header" },
+      { ANJUTA_TARGET_MAN, "ANJUTA_TARGET_MAN", "man" },
+      { ANJUTA_TARGET_INFO, "ANJUTA_TARGET_INFO", "info" },
+      { ANJUTA_TARGET_GENERIC, "ANJUTA_TARGET_GENERIC", "generic" },
+      { ANJUTA_TARGET_DATA, "ANJUTA_TARGET_DATA", "data" },
+      { ANJUTA_TARGET_EXTRA, "ANJUTA_TARGET_EXTRA", "extra" },
+      { ANJUTA_TARGET_INTLTOOL, "ANJUTA_TARGET_INTLTOOL", "intltool" },
+      { ANJUTA_TARGET_CONFIGURE, "ANJUTA_TARGET_CONFIGURE", "configure" },
+      { ANJUTA_TARGET_IDL, "ANJUTA_TARGET_IDL", "idl" },
+      { ANJUTA_TARGET_MKENUMS, "ANJUTA_TARGET_MKENUMS", "mkenums" },
+      { ANJUTA_TARGET_GENMARSHAL, "ANJUTA_TARGET_GENMARSHAL", "genmarshal" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static (g_intern_static_string ("AnjutaProjectTargetClass"), values);
   }
   return etype;
 }
