@@ -38,6 +38,7 @@
 #include "queue.h"
 #include "variable.h"
 
+#include <glib/gi18n.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-status.h>
@@ -56,8 +57,8 @@
  *---------------------------------------------------------------------------*/
 
 #define ICON_FILE "anjuta-debug-manager-plugin-48.png"
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-debug-manager.ui"
-#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-debug-manager.glade"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-debug-manager.xml"
+#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-debug-manager.ui"
 
 /* Plugin type
  *---------------------------------------------------------------------------*/
@@ -100,6 +101,8 @@ struct _DebugManagerPlugin
 	DmaThreads *thread;
 	DmaVariableDBase *variable;
 	
+
+	GtkWidget *user_command_dialog;
 	
 	/* Logging view */
 	IAnjutaMessageView* view;
@@ -423,7 +426,7 @@ dma_plugin_program_running (DebugManagerPlugin *this)
 	gtk_action_group_set_sensitive (this->running_group, TRUE);
 	
 	status = anjuta_shell_get_status(ANJUTA_PLUGIN (this)->shell, NULL);
-	anjuta_status_set_default (status, _("Debugger"), _("Running..."));
+	anjuta_status_set_default (status, _("Debugger"), _("Running…"));
 
 	set_program_counter(this, NULL, 0, 0);
 }
@@ -515,6 +518,9 @@ dma_plugin_debugger_stopped (DebugManagerPlugin *self, GError *err)
 	
 	state = anjuta_shell_get_status(ANJUTA_PLUGIN (self)->shell, NULL);
 	anjuta_status_set_default (state, _("Debugger"), NULL);
+
+	/* Remove user command dialog if existing */
+	if (self->user_command_dialog) gtk_widget_destroy (GTK_WIDGET (self->user_command_dialog));
 	
 	/* Display a warning if debugger stop unexpectedly */
 	if (err != NULL)
@@ -705,22 +711,36 @@ on_debugger_command_entry_activate (GtkEntry *entry, DebugManagerPlugin *plugin)
 static void
 on_debugger_custom_command_activate (GtkAction * action, DebugManagerPlugin *plugin)
 {
-        GladeXML *gxml;
-        GtkWidget *win, *entry;
+	if (plugin->user_command_dialog == NULL)
+	{
+        GtkBuilder *bxml;
+        GtkWidget *entry;
 
-        gxml = glade_xml_new (GLADE_FILE, "debugger_command_dialog", NULL);
-        win = glade_xml_get_widget (gxml, "debugger_command_dialog");
-        entry = glade_xml_get_widget (gxml, "debugger_command_entry");
+		bxml = anjuta_util_builder_new (GLADE_FILE, NULL);
+		if (!bxml) return;
+		anjuta_util_builder_get_objects (bxml,
+		    "debugger_command_dialog", &plugin->user_command_dialog,
+		    "debugger_command_entry", &entry,
+		    NULL);
+        g_object_unref (bxml);
 
-        gtk_window_set_transient_for (GTK_WINDOW (win),
-                                                                  GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell));
-        g_signal_connect_swapped (win, "response",
+	    gtk_window_set_transient_for (GTK_WINDOW (plugin->user_command_dialog), GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell));
+
+		g_object_add_weak_pointer (G_OBJECT (plugin->user_command_dialog), (gpointer *)&plugin->user_command_dialog);
+	
+        g_signal_connect_swapped (plugin->user_command_dialog, "response",
                                                           G_CALLBACK (gtk_widget_destroy),
-                                                          win);
+                                                         plugin->user_command_dialog);
         g_signal_connect (entry, "activate",
                                           G_CALLBACK (on_debugger_command_entry_activate),
                                           plugin);
-        g_object_unref (gxml);
+
+		gtk_widget_show_all (GTK_WIDGET (plugin->user_command_dialog));
+	}
+	else
+	{
+		gtk_window_present (GTK_WINDOW (plugin->user_command_dialog));
+	}
 }
 
 /* Info callbacks
@@ -830,7 +850,7 @@ static GtkActionEntry actions_start[] =
 	{
 		"ActionDebuggerAttachProcess",
 		"debugger-attach",
-		N_("_Debug Process..."),
+		N_("_Debug Process…"),
 		NULL,
 		N_("Start debugger and attach to a running program"),
 		G_CALLBACK (on_attach_to_project_action_activate)
@@ -838,7 +858,7 @@ static GtkActionEntry actions_start[] =
 	{
 		"ActionDebuggerDebugRemote",
 		"debugger-remote-target",
-		N_("Debug _Remote Target..."),
+		N_("Debug _Remote Target…"),
 		NULL,
 		N_("Connect to a remote debugging target"),
 		G_CALLBACK (on_start_remote_debug_action_activate),
@@ -854,7 +874,7 @@ static GtkActionEntry actions_start[] =
 	{
 		"ActionDebuggerAddSource",
 		NULL,
-		N_("Add source paths..."), 
+		N_("Add source paths…"), 
 		NULL,
 		N_("Add additional source paths"),
 		G_CALLBACK (on_add_source_activate)
@@ -866,7 +886,7 @@ static GtkActionEntry actions_loaded[] =
 	{
 		"ActionGdbCommand",                              /* Action name */
 		NULL,                                            /* Stock icon, if any */
-		N_("Debugger Command..."),                       /* Display label */
+		N_("Debugger Command…"),                       /* Display label */
 		NULL,                                            /* short-cut */
 		N_("Custom debugger command"),                   /* Tooltip */ 
 		G_CALLBACK (on_debugger_custom_command_activate) /* action callback */
@@ -916,7 +936,7 @@ static GtkActionEntry actions_loaded[] =
 		NULL,
 		N_("Shared Libraries"),
 		NULL,
-		N_("Show shared libraries mappings"),
+		N_("Show shared library mappings"),
 		G_CALLBACK (on_debugger_sharedlibs_activate)
 	},
 	{
@@ -960,7 +980,7 @@ static GtkActionEntry actions_stopped[] =
 		"debugger-step-out",
 		N_("Step _Out"),                    
 		"<shift>F5",                              
-		N_("Single step out of the function"), 
+		N_("Single step out of function"), 
 		G_CALLBACK (on_step_out_action_activate) 
 	},
 	{
@@ -974,7 +994,7 @@ static GtkActionEntry actions_stopped[] =
 	{
 		"ActionGdbCommand",
 		NULL,
-		N_("Debugger Command..."),
+		N_("Debugger Command…"),
 		NULL,
 		N_("Custom debugger command"),
 		G_CALLBACK (on_debugger_custom_command_activate)
@@ -1016,7 +1036,7 @@ static GtkActionEntry actions_stopped[] =
 		NULL,
 		N_("Shared Libraries"),
 		NULL,
-		N_("Show shared libraries mappings"),
+		N_("Show shared library mappings"),
 		G_CALLBACK (on_debugger_sharedlibs_activate)
 	},
 	{
@@ -1051,7 +1071,7 @@ dma_plugin_activate (AnjutaPlugin* plugin)
 	static gboolean initialized = FALSE;
 	AnjutaUI *ui;
 	
-	DEBUG_PRINT ("%s", "DebugManagerPlugin: Activating Debug Manager plugin...");
+	DEBUG_PRINT ("%s", "DebugManagerPlugin: Activating Debug Manager plugin…");
 	this = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
 	
     if (!initialized)
@@ -1155,14 +1175,14 @@ dma_plugin_deactivate (AnjutaPlugin* plugin)
 	DebugManagerPlugin *this;
 	AnjutaUI *ui;
 
-	DEBUG_PRINT ("%s", "DebugManagerPlugin: Deactivating Debug Manager plugin...");
+	DEBUG_PRINT ("%s", "DebugManagerPlugin: Deactivating Debug Manager plugin…");
 
 	this = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
 
 	/* Stop debugger */
 	dma_plugin_debugger_stopped (this, 0);
 
-	g_signal_handlers_disconnect_matched (plugin->shell, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, plugin);	
+	g_signal_handlers_disconnect_by_func (plugin->shell, G_CALLBACK (on_session_save), plugin);
 	g_signal_handlers_disconnect_matched (plugin, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, plugin);	
 
 	anjuta_plugin_remove_watch (plugin, this->project_watch_id, FALSE);
@@ -1255,6 +1275,8 @@ dma_plugin_instance_init (GObject* obj)
 	plugin->signals = NULL;
 	plugin->sharedlibs = NULL;
 	plugin->view = NULL;
+
+	plugin->user_command_dialog = NULL;
 	
 	/* plugin->uri = NULL; */
 }
@@ -1267,6 +1289,10 @@ dma_plugin_instance_init (GObject* obj)
 static void
 dma_plugin_dispose (GObject* obj)
 {
+	DebugManagerPlugin *plugin = ANJUTA_PLUGIN_DEBUG_MANAGER (obj);
+	
+	if (plugin->user_command_dialog != NULL)	gtk_widget_destroy (GTK_WIDGET (plugin->user_command_dialog));
+
 	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
