@@ -36,15 +36,18 @@
 /*#define DEBUG*/
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/resources.h>
+#include <libanjuta/anjuta-project.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-builder.h>
 #include <libanjuta/interfaces/ianjuta-file-savable.h>
 #include <libanjuta/anjuta-utils.h>
 
-#include <glade/glade-xml.h>
-#include <gio/gio.h>
+#include <gconf/gconf-client.h>
 
+#include <gio/gio.h>
+#include <glib/gi18n.h>
+#include <stdlib.h>
 #include <errno.h>
 #include <sys/stat.h>
 #include <ctype.h>
@@ -93,7 +96,7 @@ enum {
 };
 
 static char *column_names[COLUMNS_NB] = {
-	N_("Pid"), N_("User"), N_("Time"), N_("Command")
+	N_("PID"), N_("User"), N_("Time"), N_("Command")
 };
 
 enum {
@@ -136,7 +139,7 @@ struct _DmaStart
 #define ADD_SOURCE_DIALOG "source_paths_dialog"
 #define SOURCE_ENTRY "src_entry"
 #define SOURCE_LIST "src_clist"
-#define ADD_BUTTON "add_button"
+#define ADD_BUTTON "source_paths_add_button"
 #define REMOVE_BUTTON "remove_button"
 #define UP_BUTTON "up_button"
 #define DOWN_BUTTON "down_button"
@@ -150,6 +153,9 @@ struct _DmaStart
 #define SERIAL_RADIO "serial_radio"
 #define SERIAL_CONTAINER "serial_container"
 
+#define CHECK_DEBUG_DIALOG "check_debug_dialog"
+#define DO_NOT_SHOW_CHECK "hide_checkbox"
+
 /* Constants
  *---------------------------------------------------------------------------*/
 
@@ -162,6 +168,8 @@ struct _DmaStart
 #define RUN_PROGRAM_ACTION_GROUP "ActionGroupRun"
 #define RUN_PROGRAM_PARAMETER_ACTION "ActionProgramParameters"
 
+#define GCONF_NOT_CHECK_DEBUG "/apps/anjuta/debug_manager/silent_non_debug_config"
+
 static void attach_process_clear (AttachProcess * ap, gint ClearRequest);
 
 /* Helper functions
@@ -189,7 +197,7 @@ get_source_directories (AnjutaPlugin *plugin)
 	g_free (cwd);
 
 	/* Check if a project is already open */
-	anjuta_shell_get_value (plugin->shell, "project_root_uri", &value, NULL);
+	anjuta_shell_get_value (plugin->shell, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI, &value, NULL);
 	
 	/* Set source file search directories */
 	if (g_value_get_string (&value) != NULL)
@@ -201,12 +209,12 @@ get_source_directories (AnjutaPlugin *plugin)
 		{
 			slibs_dirs =
 				ianjuta_project_manager_get_targets (pm,
-					IANJUTA_PROJECT_MANAGER_TARGET_SHAREDLIB,
-												  NULL);
+					ANJUTA_TARGET_SHAREDLIB,
+				    NULL);
 			libs_dirs =
 				ianjuta_project_manager_get_targets (pm,
-					IANJUTA_PROJECT_MANAGER_TARGET_STATICLIB,
-												  NULL);
+					ANJUTA_TARGET_STATICLIB,
+				    NULL);
 		}
 	}
 	slibs_dirs = g_list_reverse (slibs_dirs);
@@ -215,18 +223,20 @@ get_source_directories (AnjutaPlugin *plugin)
 	node = slibs_dirs;
 	while (node)
 	{
-		gchar *dir_uri;
-		dir_uri = g_path_get_dirname (node->data);
-		search_dirs = g_list_prepend (search_dirs, dir_uri);
+		gchar *path;
+		GFile *parent = g_file_get_parent (node->data);
+		path = g_file_get_uri (parent);
+		g_object_unref (parent);
+		search_dirs = g_list_prepend (search_dirs, path);
 		node = g_list_next (node);
 	}
 	
 	node = libs_dirs;
 	while (node)
 	{
-		gchar *dir_uri;
-		dir_uri = g_path_get_dirname (node->data);
-		search_dirs = g_list_prepend (search_dirs, dir_uri);
+		gchar *path;
+		path = g_file_get_path (node->data);
+		search_dirs = g_list_prepend (search_dirs, path);
 		node = g_list_next (node);
 	}
 	
@@ -719,7 +729,6 @@ on_toggle_process_tree (GtkToggleButton *togglebutton, AttachProcess * ap)
 static pid_t
 attach_process_show (AttachProcess * ap, GtkWindow *parent)
 {
-	GladeXML *gxml;
 	GtkTreeView *view;
 	GtkTreeStore *store;
 	GtkCellRenderer *renderer;
@@ -734,16 +743,18 @@ attach_process_show (AttachProcess * ap, GtkWindow *parent)
 
 	if (!ap->dialog)
 	{
-		gxml = glade_xml_new (GLADE_FILE, "attach_process_dialog", NULL);
-		ap->dialog = glade_xml_get_widget (gxml, "attach_process_dialog");
-		ap->treeview = glade_xml_get_widget (gxml, "attach_process_tv");
-		checkb_hide_paths = GTK_CHECK_BUTTON (
-								glade_xml_get_widget (gxml, "checkb_hide_paths"));
-		checkb_hide_params = GTK_CHECK_BUTTON (
-								glade_xml_get_widget (gxml, "checkb_hide_params"));
-		checkb_process_tree = GTK_CHECK_BUTTON (
-								glade_xml_get_widget (gxml, "checkb_process_tree"));
-		g_object_unref (gxml);
+		GtkBuilder *bxml;
+
+		bxml = anjuta_util_builder_new (GLADE_FILE, NULL);
+		if (!bxml) return 0;
+		anjuta_util_builder_get_objects (bxml,
+		    "attach_process_dialog", &ap->dialog,
+		    "attach_process_tv", &ap->treeview,
+		    "checkb_hide_paths", &checkb_hide_paths,
+		    "checkb_hide_params", &checkb_hide_params,
+ 			"checkb_process_tree", &checkb_process_tree,
+		    NULL);
+		g_object_unref (bxml);
 	
 		view = GTK_TREE_VIEW (ap->treeview);
 		store = gtk_tree_store_new (COLUMNS_NB,
@@ -820,6 +831,51 @@ attach_process_destroy (AttachProcess * ap)
 	g_free (ap);
 }
 
+/* Check debug configuration dialog
+ *---------------------------------------------------------------------------*/
+
+static gboolean
+show_check_debug_dialog (DmaStart *this)
+{
+	GConfClient *client;
+	gboolean no_check_debug;
+	gint res = GTK_RESPONSE_OK;
+
+	client = gconf_client_get_default ();
+	no_check_debug = gconf_client_get_bool (client, GCONF_NOT_CHECK_DEBUG, NULL);
+	
+	if (!no_check_debug)
+	{
+		GtkBuilder *bxml;
+		GtkWindow *parent;
+		GtkWidget *dialog;
+		GtkToggleButton *do_not_show;
+		
+		parent = GTK_WINDOW (this->plugin->shell);
+
+		/* Fetch out the widget we care about for now */
+		bxml = anjuta_util_builder_new (GLADE_FILE, NULL);
+		if (!bxml) return FALSE;
+			anjuta_util_builder_get_objects (bxml,
+	    	CHECK_DEBUG_DIALOG, &dialog,
+	    	DO_NOT_SHOW_CHECK, &do_not_show,
+		    NULL);
+		g_object_unref (bxml);
+	
+		res = gtk_dialog_run (GTK_DIALOG (dialog));
+	
+		if (gtk_toggle_button_get_active	(do_not_show))
+		{
+			gconf_client_set_bool (client, GCONF_NOT_CHECK_DEBUG, TRUE, NULL);
+		}
+	
+		gtk_widget_destroy (dialog);
+	}
+
+	return res == GTK_RESPONSE_OK;
+}
+
+
 /* Load file private functions
  *---------------------------------------------------------------------------*/
 
@@ -919,7 +975,7 @@ load_target (DmaStart *this, const gchar *target)
 	if (mime_type == NULL)
 	{
 		anjuta_util_dialog_error(GTK_WINDOW (this->plugin->shell),
-				_("Unable to detect mime-type of %s. Debugger cannot start."), target);
+				_("Unable to detect MIME type of %s. Debugger cannot start."), target);
 		g_object_unref (file_info);
 		g_object_unref (file);
 		return FALSE;
@@ -983,6 +1039,9 @@ check_target (DmaStart *this, const gchar *target)
 	builder = anjuta_shell_get_interface (this->plugin->shell, IAnjutaBuilder, NULL);
 	if (builder != NULL)
 	{
+		GList *cfg_list;
+		GList *found;
+		
 		if (this->build_target)
 		{
 			/* a build operation is currently running */
@@ -997,6 +1056,17 @@ check_target (DmaStart *this, const gchar *target)
 				ianjuta_builder_cancel (builder, this->build_handle, NULL);
 			}
 		}
+
+		/* Check if debug configuration is used */
+		cfg_list = ianjuta_builder_list_configuration (builder, NULL);
+		found = g_list_find_custom(cfg_list, IANJUTA_BUILDER_CONFIGURATION_DEBUG, (GCompareFunc)strcmp);
+		if (found != NULL)
+		{
+			if (ianjuta_builder_get_uri_configuration (builder, target, NULL) != found->data)
+			{
+				if (!show_check_debug_dialog (this)) return FALSE;
+			}
+		}
 		
 		this->build_target = g_strdup (target);
 
@@ -1039,7 +1109,7 @@ static void on_radio_toggled(GtkWidget* toggle_button, GtkWidget* container)
 static gboolean
 show_remote_dialog (DmaStart *this)
 {
-	GladeXML *gxml;
+	GtkBuilder *bxml;
 	GtkWindow *parent;
 	GtkWidget *dialog;
 	GtkEntry *tcpip_address_entry;
@@ -1047,32 +1117,30 @@ show_remote_dialog (DmaStart *this)
 	GtkEntry *serial_port_entry;
 	GtkToggleButton *serial_radio;
 	GtkToggleButton *tcpip_radio;
-	GtkWidget *container;
-	
+	GtkWidget *tcpip_container;
+	GtkWidget *serial_container;
 	gint res;
 
 	parent = GTK_WINDOW (this->plugin->shell);
-	gxml = glade_xml_new (GLADE_FILE, REMOTE_DEBUG_DIALOG, NULL);
-	if (gxml == NULL)
-	{
-		anjuta_util_dialog_error(parent, _("Missing file %s"), GLADE_FILE);
-		return FALSE;
-	}
 
 	/* Fetch out the widget we care about for now */
-	dialog = glade_xml_get_widget (gxml, REMOTE_DEBUG_DIALOG);
-	tcpip_address_entry = GTK_ENTRY (glade_xml_get_widget (gxml, TCPIP_ADDRESS_ENTRY));
-	tcpip_port_entry = GTK_ENTRY (glade_xml_get_widget (gxml, TCPIP_PORT_ENTRY));
-	serial_port_entry = GTK_ENTRY (glade_xml_get_widget (gxml, SERIAL_PORT_ENTRY));
-	tcpip_radio = GTK_TOGGLE_BUTTON (glade_xml_get_widget (gxml, TCPIP_RADIO));
-	serial_radio = GTK_TOGGLE_BUTTON (glade_xml_get_widget (gxml, SERIAL_RADIO));
-	
+	bxml = anjuta_util_builder_new (GLADE_FILE, NULL);
+	if (!bxml) return FALSE;
+	anjuta_util_builder_get_objects (bxml,
+	    REMOTE_DEBUG_DIALOG, &dialog,
+	    TCPIP_ADDRESS_ENTRY, &tcpip_address_entry,
+	    TCPIP_PORT_ENTRY, &tcpip_port_entry,
+	    SERIAL_PORT_ENTRY, &serial_port_entry,
+	    TCPIP_RADIO, &tcpip_radio,
+	    SERIAL_RADIO, &serial_radio,
+	    TCPIP_CONTAINER, &tcpip_container,
+	    SERIAL_CONTAINER, &serial_container,
+	    NULL);
+	g_object_unref (bxml);
+
 	/* Connect signals */	
-	container = glade_xml_get_widget (gxml, TCPIP_CONTAINER);
-	g_signal_connect (G_OBJECT (tcpip_radio), "toggled", G_CALLBACK (on_radio_toggled), container);
-	container = glade_xml_get_widget (gxml, SERIAL_CONTAINER);
-	g_signal_connect (G_OBJECT (serial_radio), "toggled", G_CALLBACK (on_radio_toggled), container);	
-	g_object_unref (gxml);
+	g_signal_connect (G_OBJECT (tcpip_radio), "toggled", G_CALLBACK (on_radio_toggled), tcpip_container);
+	g_signal_connect (G_OBJECT (serial_radio), "toggled", G_CALLBACK (on_radio_toggled), serial_container);	
 
 	/* Populate the remote target */
 	if (this->remote_debugger)
@@ -1236,36 +1304,36 @@ static void
 add_source_show (DmaStart *this)
 {
 	AddSourceDialog dlg;
-	GladeXML *gxml;
+	GtkBuilder *bxml;
 	GtkWidget *widget;
 	GtkWindow *parent;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
-	GObject *button;
-	
+	GObject *add_button;
+	GObject *remove_button;
+	GObject *up_button;
+	GObject *down_button;
+
 	parent = GTK_WINDOW (this->plugin->shell);
-	gxml = glade_xml_new (GLADE_FILE, ADD_SOURCE_DIALOG, NULL);
-	if (gxml == NULL)
-	{
-		anjuta_util_dialog_error(parent, _("Missing file %s"), GLADE_FILE);
-		return;
-	}
-		
-	widget = glade_xml_get_widget (gxml, ADD_SOURCE_DIALOG);
-	dlg.tree = GTK_TREE_VIEW (glade_xml_get_widget (gxml, SOURCE_LIST));
-	dlg.entry = GTK_FILE_CHOOSER (glade_xml_get_widget (gxml, SOURCE_ENTRY));
+
+	bxml = anjuta_util_builder_new (GLADE_FILE, NULL);
+	if (!bxml) return;
+	anjuta_util_builder_get_objects (bxml,
+	    ADD_SOURCE_DIALOG, &widget,
+	    SOURCE_LIST, &dlg.tree,
+	    SOURCE_ENTRY, &dlg.entry,
+	    ADD_BUTTON, &add_button,
+	    REMOVE_BUTTON, &remove_button,
+	    UP_BUTTON, &up_button,
+	    DOWN_BUTTON, &down_button,
+	    NULL),
+	g_object_unref (bxml);
 	
 	/* Connect signals */	
-	button = G_OBJECT (glade_xml_get_widget (gxml, ADD_BUTTON));
-	g_signal_connect (button, "clicked", G_CALLBACK (on_source_add_button), &dlg);
-	button = G_OBJECT (glade_xml_get_widget (gxml, REMOVE_BUTTON));
-	g_signal_connect (button, "clicked", G_CALLBACK (on_source_remove_button), &dlg);
-	button = G_OBJECT (glade_xml_get_widget (gxml, UP_BUTTON));
-	g_signal_connect (button, "clicked", G_CALLBACK (on_source_up_button), &dlg);
-	button = G_OBJECT (glade_xml_get_widget (gxml, DOWN_BUTTON));
-	g_signal_connect (button, "clicked", G_CALLBACK (on_source_down_button), &dlg);
-	
-	g_object_unref (gxml);
+	g_signal_connect (add_button, "clicked", G_CALLBACK (on_source_add_button), &dlg);
+	g_signal_connect (remove_button, "clicked", G_CALLBACK (on_source_remove_button), &dlg);
+	g_signal_connect (up_button, "clicked", G_CALLBACK (on_source_up_button), &dlg);
+	g_signal_connect (down_button, "clicked", G_CALLBACK (on_source_down_button), &dlg);
 
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Path"), renderer, "text", 0, NULL);
@@ -1273,7 +1341,7 @@ add_source_show (DmaStart *this)
 	gtk_tree_view_append_column (dlg.tree, column);
 	gtk_tree_view_set_expander_column(dlg.tree, column);
 	
-	dlg.model = gtk_list_store_new (1, GTK_TYPE_STRING);
+	dlg.model = gtk_list_store_new (1, G_TYPE_STRING);
 	gtk_tree_view_set_model (dlg.tree, GTK_TREE_MODEL (dlg.model));
 	
 	gtk_window_set_transient_for (GTK_WINDOW (widget), parent);
@@ -1308,6 +1376,7 @@ add_source_show (DmaStart *this)
 	gtk_widget_destroy (widget);
 }
 
+
 /* Public functions
  *---------------------------------------------------------------------------*/
 
