@@ -22,7 +22,6 @@
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/anjuta-preferences.h>
 #include <libanjuta/anjuta-debug.h>
-#include <libanjuta/anjuta-message-area.h>
 #include <libanjuta/interfaces/ianjuta-file.h>
 #include <libanjuta/interfaces/ianjuta-markable.h>
 #include <libanjuta/interfaces/ianjuta-file-savable.h>
@@ -289,15 +288,54 @@ on_notebook_tab_btnpress (GtkWidget *wid, GdkEventButton *event, AnjutaDocman* d
 {
 	if (event->type == GDK_BUTTON_PRESS && event->button != 3)	/* right-click is for menu */
 		docman->priv->tab_pressed = TRUE;
-
+	
 	return FALSE;
 }
 
 static gboolean
 on_notebook_tab_btnrelease (GtkWidget *widget, GdkEventButton *event, AnjutaDocman* docman)
 {
+	AnjutaDocmanPage *page;
+	AnjutaDocmanPage *curr_page = NULL;
+	
 	docman->priv->tab_pressed = FALSE;
 
+	/* close on middle click */
+	if (event->button == 2)
+	{
+		/* the close function works only on the current document */
+		GList* node;
+		for (node = docman->priv->pages; node != NULL; node = g_list_next (node))
+		{
+			page = (AnjutaDocmanPage *) node->data;
+			if (page->box == widget)
+			{
+				/* we've found the page that user wants to close. Save the current
+				 * page for a later setup
+				 */
+				curr_page = anjuta_docman_get_current_page (docman);
+				anjuta_docman_set_current_document (docman, page->doc);
+				break;
+			}
+		}
+		if (node == NULL)
+			return FALSE;		
+
+		if (page != NULL) 
+		{
+			on_close_file_activate (NULL, docman->priv->plugin);
+
+			if (curr_page != NULL)
+			{
+				/* set the old current page */
+				anjuta_docman_set_current_document (docman, curr_page->doc);
+			}		
+		}
+
+		return FALSE;
+	}	
+
+	/* normal button click close */
 	if (anjuta_preferences_get_bool (docman->priv->preferences, EDITOR_TABS_RECENT_FIRST))
 	{
 		GList *node;
@@ -601,7 +639,7 @@ anjuta_docman_open_file (AnjutaDocman *docman)
 		docman->priv->fileselection =
 			create_file_open_dialog_gui(GTK_WINDOW (parent), docman);
 	}
-	if (GTK_WIDGET_VISIBLE (docman->priv->fileselection))
+	if (gtk_widget_get_visible (docman->priv->fileselection))
 		gtk_window_present (GTK_WINDOW (docman->priv->fileselection));
 	else
 		gtk_widget_show (docman->priv->fileselection);
@@ -938,13 +976,12 @@ on_document_destroy (IAnjutaDocument *doc, AnjutaDocman *docman)
 	
 	if (!docman->priv->shutingdown)
 	{
-		if (GTK_NOTEBOOK (docman)->children == NULL)
+		if ((page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (docman))) == -1)
 			anjuta_docman_set_current_document (docman, NULL);
 		else
 		{
 			AnjutaDocmanPage *next_page;
 			/* set a replacement active document */
-			page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (docman));
 			next_page = anjuta_docman_get_nth_page (docman, page_num);
 			anjuta_docman_set_current_document (docman, next_page->doc);
 		}
@@ -1052,7 +1089,7 @@ anjuta_docman_get_current_focus_widget (AnjutaDocman *docman)
 {
 	GtkWidget *widget;
 	widget = gtk_widget_get_toplevel (GTK_WIDGET (docman));
-	if (GTK_WIDGET_TOPLEVEL (widget) &&
+	if (gtk_widget_is_toplevel (widget) &&
 		gtk_window_has_toplevel_focus (GTK_WINDOW (widget)))
 	{
 		return gtk_window_get_focus (GTK_WINDOW (widget));
